Generic LLM prompt sender This function is a generic method for sending prompts to a remote or local LLM API. It dispatches to the appropriate method based on the class of the `api` argument.
send_prompt.RdGeneric LLM prompt sender This function is a generic method for sending prompts to a remote or local LLM API. It dispatches to the appropriate method based on the class of the `api` argument.