Send a prompt to a remote LLM API (e.g., OpenAI, DeepSeek) This function sends a prompt to the remote LLM API and returns the response in a structured format.
send_prompt.RemoteLlmApi.RdSend a prompt to a remote LLM API (e.g., OpenAI, DeepSeek) This function sends a prompt to the remote LLM API and returns the response in a structured format.
Usage
# S3 method for class 'RemoteLlmApi'
send_prompt(api, prompt_config)